==> engenius-0.1.1.tar.gz: lib/engenius.dart <==
library engenius;
import 'dart:async';
import 'dart:typed_data';
import 'dart:convert';
import 'servicioPost.dart';
import 'package:flutter/services.dart';

/// A Calculator.
class Engenius {
  var _usuario = "Desarrollador";
  var _pass = "123456789";
  static const MethodChannel channel =
      const MethodChannel('flutter_nfc_mifare');
  static String idcard = '';
  static Future<bool> get isMF1Here async {
    return await channel.invokeMethod('isMF1Here');
  }

  static Future<bool> get habilitar async {
    return await channel.invokeMethod('habilitar');
  }

  static Future<List> LeerEnviar() async{
    //Uint8List key = Uint8List.fromList([255, 255, 255, 255, 255, 255]);
    Uint8List key = Uint8List.fromList([175, 106, 4, 215, 181, 11]);
    print('Esta es la llave de acceso: ${key.toString()}');
    var resultado = await readMF1(1, 1, key);
    var data = resultado.join().toString()
          .replaceAll("[", "")
          .replaceAll("]", "")
          .replaceAll(" ", "");
    var _idcard = data.substring(0, 8);
    idcard = _idcard;
    var jsonObj = jsonEncode(<String, String>{
      "option": "infoinicial",
      "IdCard": _idcard,
      "DataCard": data
    });
    print(jsonDecode(jsonObj));
    var urlNew = Uri.https('www.php.engenius.com.co', '/Recargas/DatabaseRecargas2.php');
    PostData dataCoin = PostData(urlAPI: urlNew, bodyObj: jsonObj);
    var dataLocal = await dataCoin.getCoinData();
    print('dataLocal: ${dataLocal}');
    if (dataLocal['auten'][0][0] == 'VRD') {
      print('Cambiar de pagina');
      if(dataLocal['Beneficiario'][0] == null) {
        print("USUARIO NO REGISTRADO EN LA PLATAFORMA");
        var respuestamal = ["ERR"];
        return await respuestamal;
      } else {
        var respuestaok = [dataLocal['Beneficiario'][0][1].toString(),
        dataLocal['Beneficiario'][0][2].toString(),
        dataLocal['Beneficiario'][0][4].toString(),
        dataLocal['Beneficiario'][0][5].toString(),
        dataLocal['plans']['cost'][0][0].toString(),
        _idcard
        ];
        print("Usuario: " +
          dataLocal['Beneficiario'][0][1].toString() +
          '\r\n' +
          "Documento: " +
          dataLocal['Beneficiario'][0][2].toString() +
          '\r\n' +
          "Tipo Instalación: " +
          dataLocal['Beneficiario'][0][4].toString() +
          '\r\n' +
          "Ultima Recarga: " +
          dataLocal['Beneficiario'][0][5].toString() +
          '\r\n' +
          "Valor a Pagar: " +
          dataLocal['plans']['cost'][0].toString() +
          '\r\n');
          return await respuestaok;
      }
    }
  }

  static Future<String> recargar(idcard, valor, pass, usuario) async {
    var jsonObj = jsonEncode(<String, String>{
      "option": "recarga",
      "IdCard": idcard,
      "Password": pass,
      "Topup_Quantity": "30",
      "Topup_Type_Id": "1",
      "Topup_Value": valor.toString(),
      "User": usuario
    });
    print(jsonDecode(jsonObj));
    var urlNew = Uri.https("www.php.engenius.com.co", "/Recargas/DatabaseRecargas2.php");

    PostData dataCoin = PostData(urlAPI: urlNew, bodyObj: jsonObj);
    var dataLocal = await dataCoin.getCoinData();
    print('dataLocal: ${dataLocal}');
    if (dataLocal['auten'][0][0] == 'VRD') {
      print('TOKEN');
      var respuesta = await write(dataLocal['Token'][0].toString());
      if(respuesta == "true"){
        return "true";
      } else {
        return "false";
      }
      //"PIN DE RECARGA: " + dataLocal['Token'][0].toString() + '\r\n';
      //_token = dataLocal['Token'][0].toString();
    } else {
      return "false";
    }
  }

  static Future<List> readMF1(
      int sectorIndex, int blockIndex, Uint8List key) async {
    var _resultado = new List(64);
    var _lectura;
    var cont = 0;
    for (var i = 0; i < 16; i++) {
      for (var j = 0; j < 4; j++) {
        _lectura = await channel.invokeMethod('readMF1', [i, j, key]);
        print(_lectura);
        if (_lectura == null) {
          _lectura = 'Login Fail';
        }
        _resultado[cont] = _lectura;
        cont = cont + 1;
        if (cont == 64) {
          return await procesar(_resultado);
        }
      }
    }
  }

  static Future<List> procesar(List resultado) async {
    var listado = new List(64);
    var cont = 0;
    var texto = '';
    for (var i = 0; i < resultado.length; i++) {
      texto = '';
      if (resultado[i] == 'Login Fail') {
        texto = 'Login Fail';
      } else {
        for (var j = 0; j < 16; j++) {
          texto = texto + resultado[i][j].toRadixString(16);
        }
      }
      listado[i] = texto + '';
      cont = cont + 1;
      if (cont == 64) {
        return await listado;
      }
    }
  }


  static Future<String> write(token) async {
    Uint8List key = Uint8List.fromList([175, 106, 4, 215, 181, 11]);
    print('Esta es la llave de acceso: ${key.toString()}');
    await writeMF1(token, key).then((value) {
      print(value);
      if (value == true) {
        return "true";
      } else{
        return "false";
      }
    });
  }

    static Future<bool> writeMF1(String token, Uint8List key) async {
    var cont = false;
    var listado = new List(5);
    var listadoDef = new List(5);
    var b1 = token.substring(0, 32);
    var b2 = token.substring(32, 64);
    var b3 = token.substring(64, 96);
    var b4 = token.substring(96, 128);
    var b5 = token.substring(128, 160);
    listado = [b1, b2, b3, b4, b5];
    print(listado.toString());
    for (var i = 0; i < listado.length; i++) {
      listadoDef[i] = new Uint8List(16);
      listadoDef[i][0] = int.parse(listado[i].substring(0, 2), radix: 16);
      listadoDef[i][1] = int.parse(listado[i].substring(2, 4), radix: 16);
      listadoDef[i][2] = int.parse(listado[i].substring(4, 6), radix: 16);
      listadoDef[i][3] = int.parse(listado[i].substring(6, 8), radix: 16);
      listadoDef[i][4] = int.parse(listado[i].substring(8, 10), radix: 16);
      listadoDef[i][5] = int.parse(listado[i].substring(10, 12), radix: 16);
      listadoDef[i][6] = int.parse(listado[i].substring(12, 14), radix: 16);
      listadoDef[i][7] = int.parse(listado[i].substring(14, 16), radix: 16);
      listadoDef[i][8] = int.parse(listado[i].substring(16, 18), radix: 16);
      listadoDef[i][9] = int.parse(listado[i].substring(18, 20), radix: 16);
      listadoDef[i][10] = int.parse(listado[i].substring(20, 22), radix: 16);
      listadoDef[i][11] = int.parse(listado[i].substring(22, 24), radix: 16);
      listadoDef[i][12] = int.parse(listado[i].substring(24, 26), radix: 16);
      listadoDef[i][13] = int.parse(listado[i].substring(26, 28), radix: 16);
      listadoDef[i][14] = int.parse(listado[i].substring(28, 30), radix: 16);
      listadoDef[i][15] = int.parse(listado[i].substring(30, 32), radix: 16);
    }
    print(listadoDef.toString());
    var result = await channel
        .invokeMethod('writeMF1', [0, 1, key, listadoDef[0]])
        .then((value) => channel
            .invokeMethod('writeMF1', [0, 2, key, listadoDef[1]])
            .then((value) => channel
                .invokeMethod('writeMF1', [1, 0, key, listadoDef[2]])
                .then((value) => channel
                    .invokeMethod('writeMF1', [1, 1, key, listadoDef[3]])
                    .then((value) => channel.invokeMethod('writeMF1',
                            [1, 2, key, listadoDef[4]]).then((value) {
                          print('TERMINE TODO');
                            return true;
                        }).catchError((error) => print('ERROR3')))
                    .catchError((error) => print('ERROR3')))
                .catchError((error) => print('ERROR2')))
            .catchError((error) => print('ERROR1')))
        .catchError((error) => print('ERROR0'));

        return result;
  }

  static Future<bool> writeMF2(
      int sectorIndex, int blockIndex, Uint8List key, Uint8List data) async {
    return await channel
        .invokeMethod('writeMF1', [sectorIndex, blockIndex, key, data]);
  }


}

==> engenius-0.1.3.tar.gz: lib/engenius.dart <==
library engenius;
import 'dart:async';
import 'dart:typed_data';
import 'dart:convert';
import 'servicioPost.dart';
import 'package:flutter/services.dart';

/// A Calculator.
class Engenius {
  static const MethodChannel channel =
      const MethodChannel('flutter_nfc_mifare');
  static String idcard = '';
  static Future<bool?> get isMF1Here async {
    return await channel.invokeMethod('isMF1Here');
  }

  static Future<bool?> get habilitar async {
    return await channel.invokeMethod('habilitar');
  }

  static Future<List> leerEnviar() async{
    //Uint8List key = Uint8List.fromList([255, 255, 255, 255, 255, 255]);
    Uint8List key = Uint8List.fromList([175, 106, 4, 215, 181, 11]);
    print('Esta es la llave de acceso: ${key.toString()}');
    var resultado = await readMF1(1, 1, key);
    var data = resultado.join().toString()
          .replaceAll("[", "")
          .replaceAll("]", "")
          .replaceAll(" ", "");
    var _idcard = data.substring(0, 8);
    idcard = _idcard;
    var jsonObj = jsonEncode(<String, String>{
      "option": "infoinicial",
      "IdCard": _idcard,
      "DataCard": data
    });
    print(jsonDecode(jsonObj));
    var urlNew = Uri.https('www.php.engenius.com.co', '/Recargas/DatabaseRecargas2.php');
    PostData dataCoin = PostData(urlAPI: urlNew, bodyObj: jsonObj);
    var dataLocal = await dataCoin.getCoinData();
    print('dataLocal: $dataLocal');
    if (dataLocal['auten'][0][0] == 'VRD') {
      print('Cambiar de pagina');
      if(dataLocal['Beneficiario'][0] == null) {
        print("USUARIO NO REGISTRADO EN LA PLATAFORMA");
        var respuestamal = ["ERR"];
        return respuestamal;
      } else {
        var respuestaok = [dataLocal['Beneficiario'][0][1].toString(),
        dataLocal['Beneficiario'][0][2].toString(),
        dataLocal['Beneficiario'][0][4].toString(),
        dataLocal['Beneficiario'][0][5].toString(),
        dataLocal['plans']['cost'][0][0].toString(),
        _idcard
        ];
        print("Usuario: " +
          dataLocal['Beneficiario'][0][1].toString() +
          '\r\n' +
          "Documento: " +
          dataLocal['Beneficiario'][0][2].toString() +
          '\r\n' +
          "Tipo Instalación: " +
          dataLocal['Beneficiario'][0][4].toString() +
          '\r\n' +
          "Ultima Recarga: " +
          dataLocal['Beneficiario'][0][5].toString() +
          '\r\n' +
          "Valor a Pagar: " +
          dataLocal['plans']['cost'][0].toString() +
          '\r\n');
          return respuestaok;
      }
    }
     return [];
  }

  static Future<String> recargar(idcard, valor, pass, usuario) async {
    var jsonObj = jsonEncode(<String, String>{
      "option": "recarga",
      "IdCard": idcard,
      "Password": pass,
      "Topup_Quantity": "30",
      "Topup_Type_Id": "1",
      "Topup_Value": valor.toString(),
      "User": usuario
    });
    print(jsonDecode(jsonObj));
    var urlNew = Uri.https("www.php.engenius.com.co", "/Recargas/DatabaseRecargas2.php");

    PostData dataCoin = PostData(urlAPI: urlNew, bodyObj: jsonObj);
    var dataLocal = await dataCoin.getCoinData();
    print('dataLocal: $dataLocal');
    if (dataLocal['auten'][0][0] == 'VRD') {
      print('TOKEN');
      var respuesta = await write(dataLocal['Token'][0].toString());
      if(respuesta == "true"){
        return "true";
      } else {
        return "false";
      }
      //"PIN DE RECARGA: " + dataLocal['Token'][0].toString() + '\r\n';
      //_token = dataLocal['Token'][0].toString();
    } else {
      return "false";
    }
  }

  static Future<List> readMF1(
      int sectorIndex, int blockIndex, Uint8List key) async {
    var _resultado = new List.filled(64,"");
    var _lectura;
    var cont = 0;
    for (var i = 0; i < 16; i++) {
      for (var j = 0; j < 4; j++) {
        _lectura = await channel.invokeMethod('readMF1', [i, j, key]);
        print(_lectura);
        if (_lectura == null) {
          _lectura = 'Login Fail';
        }
        _resultado[cont] = _lectura;
        cont = cont + 1;
        if (cont == 64) {
          return await procesar(_resultado);
        }
      }
    }
    return [];
  }

  static Future<List> procesar(List resultado) async {
    var listado = new List.filled(64,"");
    var cont = 0;
    var texto = '';
    for (var i = 0; i < resultado.length; i++) {
      texto = '';
      if (resultado[i] == 'Login Fail') {
        texto = 'Login Fail';
      } else {
        for (var j = 0; j < 16; j++) {
          texto = texto + resultado[i][j].toRadixString(16);
        }
      }
      listado[i] = texto + '';
      cont = cont + 1;
      if (cont == 64) {
        return listado;
      }
    }
    return [];
  }


  static Future<String> write(token) async {
    Uint8List key = Uint8List.fromList([175, 106, 4, 215, 181, 11]);
    print('Esta es la llave de acceso: ${key.toString()}');
    await writeMF1(token, key).then((value) {
      print("RESPUESTA ESCRIBIR");
      print(value);
      if (value == true) {
        return "true";
      } else{
        return "false";
      }
    });
    return "false";
  }

    static Future<bool> writeMF1(String token, Uint8List key) async {
    //var listado = new List.filled(5,[]);
    var listadoDef = new List.filled(5,[]);
    var b1 = token.substring(0, 32);
    var b2 = token.substring(32, 64);
    var b3 = token.substring(64, 96);
    var b4 = token.substring(96, 128);
    var b5 = token.substring(128, 160);
    var listado = [b1, b2, b3, b4, b5];
    print(listado.toString());
    for (var i = 0; i < listado.length; i++) {
      listadoDef[i] = new Uint8List(16);
      listadoDef[i][0] = int.parse(listado[i].substring(0, 2), radix: 16);
      listadoDef[i][1] = int.parse(listado[i].substring(2, 4), radix: 16);
      listadoDef[i][2] = int.parse(listado[i].substring(4, 6), radix: 16);
      listadoDef[i][3] = int.parse(listado[i].substring(6, 8), radix: 16);
      listadoDef[i][4] = int.parse(listado[i].substring(8, 10), radix: 16);
      listadoDef[i][5] = int.parse(listado[i].substring(10, 12), radix: 16);
      listadoDef[i][6] = int.parse(listado[i].substring(12, 14), radix: 16);
      listadoDef[i][7] = int.parse(listado[i].substring(14, 16), radix: 16);
      listadoDef[i][8] = int.parse(listado[i].substring(16, 18), radix: 16);
      listadoDef[i][9] = int.parse(listado[i].substring(18, 20), radix: 16);
      listadoDef[i][10] = int.parse(listado[i].substring(20, 22), radix: 16);
      listadoDef[i][11] = int.parse(listado[i].substring(22, 24), radix: 16);
      listadoDef[i][12] = int.parse(listado[i].substring(24, 26), radix: 16);
      listadoDef[i][13] = int.parse(listado[i].substring(26, 28), radix: 16);
      listadoDef[i][14] = int.parse(listado[i].substring(28, 30), radix: 16);
      listadoDef[i][15] = int.parse(listado[i].substring(30, 32), radix: 16);
    }
    print(listadoDef.toString());
    var result = await channel
        .invokeMethod('writeMF1', [0, 1, key, listadoDef[0]])
        .then((value) => channel
            .invokeMethod('writeMF1', [0, 2, key, listadoDef[1]])
            .then((value) => channel
                .invokeMethod('writeMF1', [1, 0, key, listadoDef[2]])
                .then((value) => channel
                    .invokeMethod('writeMF1', [1, 1, key, listadoDef[3]])
                    .then((value) => channel.invokeMethod('writeMF1',
                            [1, 2, key, listadoDef[4]]).then((value) {
                          print('TERMINE TODO');
                            return true;
                        }).catchError((error) => 
                         error
                        ))
                    .catchError((error) => 
                    error
                    ))
                .catchError((error) =>
                 error
                 ))
            .catchError((error) =>
            error
             ))
        .catchError((error) =>
        error
        );

        return result;
  }

  static Future<bool?> writeMF2(
      int sectorIndex, int blockIndex, Uint8List key, Uint8List data) async {
    return await channel
        .invokeMethod('writeMF1', [sectorIndex, blockIndex, key, data]);
  }


}
